@@ -1,5 +1,5 @@
-use lambda_web::warp::{self, Filter};
 use lambda_web::{is_running_on_lambda, run_warp_on_lambda, LambdaError};
+use warp::{self, Filter};
 
 #[tokio::main]
 async fn main() -> Result<(), LambdaError> {
